@@ -20,6 +20,7 @@ OC.L10N.register(
     "can edit" : "yn gallu golygu",
     "New calendar" : "Calendr newydd",
     "Cancel" : "Diddymu",
+    "Actions" : "Gweithredoedd",
     "Show week numbers" : "Dangos rhifau wythnosau",
     "Settings & import" : "Gosodiadau a mewnforio",
     "Email" : "E-bost",
@@ -31,7 +32,6 @@ OC.L10N.register(
     "More" : "Rhagor",
     "Save" : "Cadw",
     "Update" : "Diweddaru",
-    "Select Date" : "Dewis Dyddiad",
     "Personal" : "Personol",
     "Details" : "Manylion",
     "Attendees" : "Mynychwyr",
