@@ -65,6 +65,9 @@ OC.L10N.register(
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "can edit" : "voi muokata",
+    "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
+    "An error occurred, unable to change the unshare the calendar." : "Tapahtui virhe, kalenterin poissa jakamista ei voi muokata.",
+    "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
     "+ New calendar" : "+ Uusi kalenteri",
     "New calendar" : "Uusi kalenteri",
     "Creating calendar …" : "Luodaan kalenteri …",
@@ -87,16 +90,29 @@ OC.L10N.register(
     "Automatic" : "Automaattinen",
     "Automatic ({detected})" : "Automaattinen ({detected})",
     "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
+    "Shortcut overview" : "Pikakuvakenäkymä",
+    "or" : "tai",
+    "Navigation" : "Navigointi",
+    "Views" : "Näyttökertaa",
+    "Day view" : "Päivänäkymä",
+    "Week view" : "Viikkonäkymä",
+    "Month view" : "Kuukausinäkymä",
+    "Actions" : "Toiminnot",
+    "Create event" : "Luo tapahtuma",
+    "Show shortcuts" : "Näytä pikakuvakkeet",
     "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
+    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
     "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
     "Limit visible events per view" : "Rajoita näytettäviä tapahtumia näkymää kohden",
     "Show weekends" : "Näytä viikonloput",
     "Show week numbers" : "Näytä viikkonumerot",
     "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
     "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
+    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
     "Settings & import" : "Asetukset ja tuonti",
     "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
+    "before at" : "ennen",
     "Notification" : "Ilmoitus",
     "Email" : "Sähköposti",
     "Audio notification" : "Ääni-ilmoitus",
@@ -133,6 +149,7 @@ OC.L10N.register(
     "Chairperson" : "Puheenjohtaja",
     "Required participant" : "Vaadittu osallistuja",
     "Optional participant" : "Valinnainen osallistuja",
+    "Non-participant" : "Osallistumaton",
     "Remove attendee" : "Poista osallistuja",
     "Search for e-mails, users, contacts, resources or rooms" : "Hae sähköpostiosoitteita, käyttäjiä, yhteystietoja, resursseja tai huoneita",
     "No match found" : "Ei tuloksia",
@@ -156,11 +173,14 @@ OC.L10N.register(
     "third" : "kolmas",
     "fourth" : "neljäs",
     "fifth" : "viides",
+    "second to last" : "toiseksi viimeinen",
     "last" : "viimeinen",
     "Repeat" : "Toista",
     "Repeat every" : "Toista joka",
+    "By day of the month" : "Kuukauden päivän mukaan",
     "Monday" : "Maanantai",
     "weekday" : "viikonpäivä",
+    "weekend day" : "viikonloppupäivä",
     "Summary" : "Yhteenveto",
     "More" : "Lisää",
     "Save" : "Tallenna",
@@ -172,7 +192,6 @@ OC.L10N.register(
     "Please select a timezone:" : "Valitse aikavyöhyke:",
     "Pick a time" : "Valitse aika",
     "Pick a date" : "Valitse päivä",
-    "Select Date" : "Valitse päivä",
     "from {formattedDate}" : "alkaen {formattedDate}",
     "to {formattedDate}" : "päättyen {formattedDate}",
     "on {formattedDate}" : "päivänä {formattedDate}",
@@ -219,6 +238,8 @@ OC.L10N.register(
     "{time} before the event ends" : "{time} ennen tapahtuman päättymistä",
     "{time} after the event starts" : "{time} tapahtuman alkamisen jälkeen",
     "{time} after the event ends" : "{time} tapahtuman päättymisen jälkeen",
+    "on {time}" : "klo {time}",
+    "on {time} ({timezoneId})" : "klo {time} ({timezoneId})",
     "Week {number} of {year}" : "Viikko {number} vuonna {year}",
     "Does not repeat" : "Ei toistu",
     "Daily" : "Päivittäin",
@@ -227,7 +248,9 @@ OC.L10N.register(
     "Yearly" : "Vuosittain",
     "in {monthNames}" : "kuukausina {monthNames}",
     "_%n time_::_%n times_" : ["%n kerran","%n kertaa"],
+    "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
     "Untitled event" : "Nimetön tapahtuma",
+    "Untitled task" : "Nimetön tehtävä",
     "When shared show" : "Jaettaessa näytä",
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
@@ -241,6 +264,7 @@ OC.L10N.register(
     "Confirmed" : "Vahvistettu",
     "Tentative" : "Alustava",
     "Cancelled" : "Peruttu",
+    "Show as" : "Näytä muodossa",
     "Take this event into account when calculating free-busy information." : "Huomioi tämä tapahtuma laskettaessa vapaita ja varattuja ajankohtia.",
     "Free" : "Vapaa",
     "Categories" : "Luokat",
@@ -263,7 +287,9 @@ OC.L10N.register(
     "Graduation" : "Valmistujaiset",
     "Brainstorm" : "Brainstorm",
     "Baseball" : "Pesäpallo",
+    "Meet" : "Liity",
     "Planning" : "Suunnittelua",
+    "Pointing" : "Osoittaa",
     "Retrospective" : "Retrospektiivinen",
     "Review" : "Esikatsele",
     "Office" : "Toimisto",
@@ -295,6 +321,7 @@ OC.L10N.register(
     "Dentist" : "Hammaslääkäri",
     "Interview" : "Haastattelu",
     "Training" : "Treenit",
+    "Practice" : "Harjoittele",
     "Sports" : "Liikuntaa",
     "Exercise" : "Harjoitukset",
     "Work out" : "Bodausta",
@@ -310,6 +337,10 @@ OC.L10N.register(
     "Running" : "Juoksua",
     "Go for a run" : "Mene lenkille",
     "Marathon" : "Maraton",
+    "Video-conference" : "Videokonfrenssi",
+    "Video-call" : "Videopuhelu",
+    "Video-chat" : "Videokeskustelu",
+    "Video-meeting" : "Videotapaaminen",
     "Call" : "Puhelu",
     "Calling" : "Puhelu",
     "Christmas" : "Joulu",
@@ -318,6 +349,7 @@ OC.L10N.register(
     "Travelling" : "Reissaamista",
     "Journey" : "Matka",
     "Collaborate" : "Yhteistyötä",
+    "Pair" : "Yhdistä",
     "Lecture" : "Luento",
     "Seminar" : "Seminaari",
     "Photograph" : "Valokuvaus",
