@@ -72,6 +72,7 @@ OC.L10N.register(
     "New calendar" : "新しいカレンダー",
     "Creating calendar …" : "カレンダーを作成中 …",
     "New calendar with task list" : "タスクリスト付きの新しいカレンダー",
+    "New subscription from link (read-only)" : "リンクからの新規加入 (読み取り専用)",
     "Creating subscription …" : "購読を作成中 …",
     "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
@@ -81,17 +82,34 @@ OC.L10N.register(
     "Calendar to import into" : "インポートするカレンダー",
     "Cancel" : "キャンセル",
     "_Import calendar_::_Import calendars_" : ["カレンダーのインポート"],
+    "{filename} is an unsupported file-type" : "{filename} はサポートされていないファイルタイプです。",
+    "{filename} could not be parsed" : "{filename} が解析できませんでした",
+    "No valid files found, aborting import" : "有効なファイルが見つかりませんでした。インポートを中止します。",
     "Import partially failed. Imported {accepted} out of {total}." : "インポートが部分的に失敗しました。 {total}のうち{accepted}をインポートしました。",
     "_Successfully imported %n event_::_Successfully imported %n events._" : ["%nイベントを正常にインポートしました"],
     "Automatic" : "自動",
     "Automatic ({detected})" : "自動 ({detected})",
     "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
+    "Shortcut overview" : "概要",
+    "or" : "或いは",
+    "Navigation" : "ナビゲーション",
+    "Previous period" : "前の期間",
+    "Next period" : "次の期間",
+    "Views" : "表示",
+    "Day view" : "日表示",
+    "Week view" : "週表示",
+    "Month view" : "月表示",
+    "Actions" : "アクション",
+    "Create event" : "イベントを作成",
+    "Show shortcuts" : "概要の表示",
     "Enable birthday calendar" : "誕生日カレンダーを有効にする",
+    "Show tasks in calendar" : "カレンダーにタスクを表示",
     "Enable simplified editor" : "簡易エディターを有効にする",
     "Show weekends" : "週末を表示",
     "Show week numbers" : "週番号を表示する",
     "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
+    "Show keyboard shortcuts" : "キーボード ショートカット",
     "Settings & import" : "設定とインポート",
     "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
     "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
@@ -123,13 +141,15 @@ OC.L10N.register(
     "{name} marked their participation as tentative." : "{name}が参加を暫定的とマークしました。",
     "{name} did not respond to your invitation yet." : "{name}は招待にまだ返答していません。",
     "{name} did not respond to {organizerName}'s invitation yet." : "{name}は{organizerName}の招待にまだ応答していません。",
+    "Create Talk room for this event" : "このイベントに通話ルームを作成する",
+    "Error creating Talk room" : "通話ルームの作成に失敗しました",
     "Send e-mail" : "メールを送信",
     "Chairperson" : "主宰者",
     "Required participant" : "参加必須",
     "Optional participant" : "任意参加",
     "Non-participant" : "非参加",
     "Remove attendee" : "出席者を削除",
-    "Search for e-mails, users, contacts, resources or rooms" : "メール、ユーザー、連絡先、リソース、または部屋を検索する",
+    "Search for e-mails, users, contacts, resources or rooms" : "メール、ユーザー、連絡先、リソース、またはルームを検索する",
     "No match found" : "一致するものが見つかりません",
     "No attendees yet" : "出席者はまだいません",
     "(organizer)" : "（主催者）",
@@ -147,14 +167,27 @@ OC.L10N.register(
     "on date" : "日時指定",
     "after" : "後",
     "_time_::_times_" : ["回数"],
+    "first" : "初日",
+    "third" : "3日目",
+    "fourth" : "4日目",
+    "fifth" : "5日目",
+    "second to last" : "2日目から最終日",
     "Repeat" : "繰り返し",
     "Monday" : "月曜日",
+    "weekday" : "平日",
+    "weekend day" : "週末",
     "Summary" : "要約",
     "More" : "もっと見る",
     "Save" : "保存",
     "Update" : "アップデート",
     "Please select a timezone:" : "タイムゾーンを選択してください：",
-    "Select Date" : "日付を選択",
+    "Pick a time" : "時間を指定",
+    "Pick a date" : "日付を指定",
+    "from {formattedDate}" : "{formattedDate}から",
+    "to {formattedDate}" : "{formattedDate}まで",
+    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}から",
+    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}まで",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
     "Type to search timezone" : "入力してタイムゾーンを検索",
     "Personal" : "個人",
     "Details" : "詳細",
@@ -177,9 +210,19 @@ OC.L10N.register(
     "Special occasion" : "特別な用事",
     "Travel" : "旅行",
     "Vacation" : "休暇",
+    "at the event's start" : "イベント開始時",
+    "at the event's end" : "イベント終了時",
+    "{time} before the event starts" : "イベント開始 {time} 前",
+    "{time} before the event ends" : "イベント終了 {time} 前",
+    "{time} after the event starts" : "イベント開始 {time} 後",
+    "{time} after the event ends" : "イベント終了 {time} 後",
     "Week {number} of {year}" : "{year}の{number} 週",
     "Daily" : "毎日",
     "Weekly" : "毎週",
+    "_Every %n day_::_Every %n days_" : ["%n日ごと"],
+    "_Every %n week_::_Every %n weeks_" : ["%n週ごと"],
+    "_Every %n month_::_Every %n months_" : ["%n月ごと"],
+    "_Every %n year_::_Every %n years_" : ["%n年ごと"],
     "_%n time_::_%n times_" : ["%n回"],
     "Untitled event" : "無題のイベント",
     "When shared show full event" : "共有時にすべてのイベントを表示",
