@@ -28,7 +28,7 @@ OC.L10N.register(
     "Edit color" : "Уреди бои",
     "Saving color …" : "Зачувување боја …",
     "Copy private link" : "Копирај приватен линк",
-    "Download" : "Превземи",
+    "Download" : "Преземи",
     "Unshare from me" : "Не споделувај со мене",
     "Delete" : "Избриши",
     "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
@@ -80,6 +80,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events._" : ["Успешно увезен %n настан","Успешно увезени %n настани."],
     "Automatic" : "Автоматски",
     "Automatic ({detected})" : "Автоматски ({detected})",
+    "Actions" : "Акции",
     "Enable birthday calendar" : "Овозможи календар со родендени",
     "Enable simplified editor" : "Овозможи поедноставен уредувач",
     "Show weekends" : "Прикажи викенди",
@@ -159,7 +160,6 @@ OC.L10N.register(
     "Please select a timezone:" : "Изберете временска зона:",
     "Pick a time" : "Избери време",
     "Pick a date" : "Избери датум",
-    "Select Date" : "Избери датум",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
     "on {formattedDate}" : "на {formattedDate}",
@@ -181,7 +181,7 @@ OC.L10N.register(
     "Show more details" : "Прикажи повече детали",
     "Close" : "Затвори",
     "Subscribe to {name}" : "Претплатете се на {name}",
-    "Download {name}" : "Превземи {name}",
+    "Download {name}" : "Преземи {name}",
     "Anniversary" : "Годишнина",
     "Appointment" : "Назначување",
     "Business" : "Бизнис",
