@@ -23,11 +23,15 @@ OC.L10N.register(
     "Month" : "Måned",
     "Untitled calendar" : "Kalender uten tittel",
     "Edit name" : "Rediger navn",
+    "Saving name …" : "Lagrer navn ...",
     "Edit color" : "Rediger farge",
+    "Saving color …" : "Lagrer farge  ...",
     "Copy private link" : "Kopier privat lenke",
     "Download" : "Last ned",
     "Unshare from me" : "Fjern deling fra meg",
     "Delete" : "Slett",
+    "An error occurred, unable to change visibility of the calendar." : "En feil oppstod, kan ikke endre synlighet til kalenderen.",
+    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
     "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
     "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
     "An error occurred, unable to rename the calendar." : "Det oppstod en feil, klarte ikke å endre navn på kalenderen.",
@@ -39,51 +43,100 @@ OC.L10N.register(
     "Publishing calendar" : "Publiserer kalender",
     "Copy public link" : "Kopier offentlig lenke",
     "Send link to calendar via email" : "Sende lenke til kalenderen via e-post",
+    "Enter one address" : "Tast inn en adresse",
+    "Sending email …" : "Sender epost ...",
+    "Copy subscription link" : "Kopier abonnementslenke",
+    "Copying link …" : "Kopierer lenke ...",
     "Copied link" : "Kopier lenke",
     "Could not copy link" : "Klarte ikke å kopiere lenken",
+    "Copy embedding code" : "Kopier innbyggingskode",
+    "Copying code …" : "Kopierer kode ...",
     "Copied code" : "Kode kopiert",
     "Could not copy code" : "Klarte ikke å kopiere koden",
-    "Delete share link" : "Slett lenke til deling",
+    "Delete share link" : "Slett delingslenke",
+    "Deleting share link …" : "Sletter delingslenke ...",
     "An error occurred, unable to publish calendar." : "Det oppstod en feil, klarte ikke å publisere kalenderen.",
+    "An error occurred, unable to send email." : "En feil oppstod, kan ikke sende e-post.",
+    "Embed code copied to clipboard." : "Innbyggingskode kopiert til utklippstavle.",
+    "Embed code could not be copied to clipboard." : "Innbyggingskode ble ikke kopiert til utklippstavle.",
     "Unpublishing calendar failed" : "Fjerne publiseringen av kalenderen feilet.",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "can edit" : "kan endre",
     "Unshare with {displayName}" : "Fjern deling med {displayName}",
+    "An error occurred, unable to change the unshare the calendar." : "En feil oppstod, kan ikke endre fjerning av deling av kalenderen.",
+    "An error occurred, unable to change the permission of the share." : "En feil oppstod, kan ikke endre rettighetene til delingen.",
     "+ New calendar" : "+ Ny kalender",
     "New calendar" : "Ny kalender",
+    "Creating calendar …" : "Oppretter kalender ...",
     "New calendar with task list" : "Ny kalender med oppgaveliste",
+    "New subscription from link (read-only)" : "Nytt abonnement fra lenke (kun lesing)",
+    "Creating subscription …" : "Oppretter abonnement ...",
+    "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
-    "Import calendars" : "Importer kalender",
+    "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendrene.",
+    "Import calendars" : "Importer kalendere",
+    "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
     "Filename" : "Filnavn",
     "Calendar to import into" : "Kalenderen det skal importeres til",
     "Cancel" : "Avbryt",
     "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
+    "{filename} is an unsupported file-type" : "{filename} er en ustøttet filtype",
+    "{filename} could not be parsed" : "{filename} kunne ikke leses",
+    "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
+    "Import partially failed. Imported {accepted} out of {total}." : "Importering mislykkes delvis. Importerte {accepted} av {total}. ",
+    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Importerte %navtale","Importerte %n hendelser."],
     "Automatic" : "Automatisk",
     "Automatic ({detected})" : "Automatisk ({detected})",
+    "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
+    "Shortcut overview" : "Oversikt over snarveier",
+    "or" : "eller",
+    "Navigation" : "Navigasjon",
+    "Previous period" : "Forrige periode",
+    "Next period" : "Neste periode",
+    "Views" : "Visninger",
+    "Day view" : "Dagsvisning",
+    "Week view" : "Ukesvisning",
+    "Month view" : "Månedsvisning",
+    "Actions" : "Handlinger",
+    "Create event" : "Opprettet hendelse",
+    "Show shortcuts" : "Vis snarveier",
     "Enable birthday calendar" : "Aktiver fødselsdagkalender",
+    "Show tasks in calendar" : "Vis oppgaver i kalender",
     "Enable simplified editor" : "Aktiver forenklet redigering",
+    "Limit visible events per view" : "Begrens synlige hendelser i brukerutsnitt",
     "Show weekends" : "Vis helger",
     "Show week numbers" : "Vis ukenumre",
-    "Copy primary CalDAV address" : "Kopier primær CalDAV lenke",
-    "Copy iOS/macOS CalDAV address" : "Kopier iOS/macOS CalDAV lenke",
+    "Copy primary CalDAV address" : "Kopier hovedlenke til CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Kopier iOS/macOS CalDAV-lenke",
+    "Show keyboard shortcuts" : "Vis tastatursnarveier",
     "Settings & import" : "Innstillinger og import",
     "CalDAV link copied to clipboard." : "CalDAV lenke kopiert til utklippstavlen.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV lenke kunne ikke bli kopiert til utklippstavlen.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
+    "before at" : "før ved",
     "Notification" : "Varsel",
     "Email" : "E-post",
-    "Audio notification" : "Lyd varsel",
+    "Audio notification" : "Lydvarsel",
     "Other notification" : "Andre varsel",
-    "Relative to event" : "Relativ til hendelse",
+    "Relative to event" : "Relativt til hendelse",
     "On date" : "På dato",
+    "Edit time" : "Rediger tidspunkt",
+    "Save time" : "Lagre tidspunkt",
     "Remove reminder" : "Fjern påminnelse",
     "on" : "på",
+    "at" : "på",
+    "+ Add reminder" : "+Legg til påminnelse",
     "_second_::_seconds_" : ["sekund","sekunder"],
     "_minute_::_minutes_" : ["minutt","minutter"],
     "_hour_::_hours_" : ["time","timer"],
     "_day_::_days_" : ["dag","dager"],
     "_week_::_weeks_" : ["uke","uker"],
+    "No reminders yet" : "Ingen påminnelser enda",
+    "Availability of attendees, resources and rooms" : "Tilgjengelighet til deltagere, ressurser og rom",
+    "Attendees, Resources and Rooms" : "Deltagere, ressurser og rom",
+    "Busy (tentative)" : "Opptatt (foreløpig)",
     "Busy" : "Opptatt",
+    "Out of office" : "Fraværende",
     "Unknown" : "Ukjent",
     "{name} accepted your invitation." : "{name} aksepterte din invitasjon.",
     "{name} accepted {organizerName}'s invitation." : "{name} aksepterte {organizerName}s invitasjon.",
@@ -93,7 +146,12 @@ OC.L10N.register(
     "{name} marked their participation as tentative." : "{name} markerte sin deltakelse som mulig.",
     "{name} did not respond to your invitation yet." : "{name} har ikke respondert på din invitasjon enda.",
     "{name} did not respond to {organizerName}'s invitation yet." : "{name} har ikke svart på {organizerName}s invitasjon enda.",
+    "Create Talk room for this event" : "Opprett Talk-rom for denne hendelsen",
+    "Show busy times" : "Vis opptatte tider",
+    "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
+    "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
     "Send e-mail" : "Send e-post",
+    "Chairperson" : "Ordstyrer",
     "Required participant" : "Påkrevd deltaker",
     "Optional participant" : "Ønsket deltaker",
     "Non-participant" : "Ikke-deltaker",
@@ -101,6 +159,7 @@ OC.L10N.register(
     "Search for e-mails, users, contacts, resources or rooms" : "Søk for e-poster, brukere, kontakter, ressurser eller rom",
     "No match found" : "Ingen treff",
     "(organizer)" : "(organisator)",
+    "Remove color" : "Fjern farge",
     "Event title" : "Tittel på hendelsen",
     "All day" : "Hele dagen",
     "from {startDate}" : "fra {startDate}",
@@ -119,6 +178,7 @@ OC.L10N.register(
     "last" : "siste",
     "Repeat" : "Gjenta",
     "Repeat every" : "Gjenta hver",
+    "On the" : "På den",
     "_month_::_months_" : ["måned","måneder"],
     "_year_::_years_" : ["år","år"],
     "Monday" : "Mandag",
@@ -132,7 +192,18 @@ OC.L10N.register(
     "Update this and all future" : "Oppdater denne og fremtidige hendelser",
     "Public calendar does not exist" : "Offentlig kalender finnes ikke",
     "Please select a timezone:" : "Velg en tidssone:",
-    "Select Date" : "Velg dato",
+    "Pick a time" : "Velg et tidspunkt",
+    "Pick a date" : "Velg en dato",
+    "from {formattedDate}" : "fra {formattedDate}",
+    "to {formattedDate}" : "til {formattedDate}",
+    "on {formattedDate}" : "på {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} på {formattedDate}",
+    "to {formattedDate} at {formattedTime}" : "til {formattedDate} på {formattedDate}",
+    "on {formattedDate} at {formattedTime}" : "på {formattedDate} på {formattedDate}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} på {formattedDate}",
+    "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
+    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og tidspunkt",
+    "Type to search timezone" : "Skriv for å finne tidssone",
     "Personal" : "Personlig",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
@@ -143,6 +214,7 @@ OC.L10N.register(
     "Projects" : "Prosjekter",
     "Show more details" : "Vis flere detaljer",
     "Close" : "Lukk",
+    "Subscribe to {name}" : "Abonner på {name}",
     "Download {name}" : "Last ned {name}",
     "Anniversary" : "Jubileum",
     "Appointment" : "Avtale",
@@ -151,9 +223,11 @@ OC.L10N.register(
     "Holiday" : "Ferie",
     "Meeting" : "Møte",
     "Miscellaneous" : "Diverse",
+    "Non-working hours" : "Ikke-arbeidende tidspunkt",
     "Not in office" : "Ikke på kontoret",
     "Phone call" : "Telefonsamtale",
     "Sick day" : "Sykedag",
+    "Special occasion" : "Spesiell anledning",
     "Travel" : "Reise",
     "Vacation" : "Ferie",
     "Week {number} of {year}" : "Uke {number} {year}",
@@ -179,6 +253,7 @@ OC.L10N.register(
     "Search or add categories" : "Søk eller legg til kategorier",
     "Add this as a new category" : "Legg til som ny kategori",
     "Custom color" : "Tilpasset farge",
+    "Imported {filename}" : "Importerte {filename}",
     "Presentation" : "Presentasjon",
     "Review" : "Anmeldelse",
     "Office" : "Office",
