@@ -2,30 +2,49 @@ OC.L10N.register(
     "calendar",
     {
     "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
+    "Successfully sent email to " : "Email enviado com sucesso",
     "Hello," : "Olá,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informar que %s publicou o calendário »%s«.",
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "Parabéns!",
     "Calendar" : "Calendário",
+    "A Calendar app for Nextcloud" : "Uma aplicação de calendário para o Nextcloud",
     "Previous day" : "Dia anterior",
     "Previous week" : "Semana anterior",
     "Previous month" : "Mês anterior",
     "Next day" : "Dia seguinte",
+    "Next week" : "Próxima semana",
+    "Next month" : "Próximo mês",
+    "+ New event" : "+ Novo evento",
     "Today" : "Hoje",
     "Day" : "Dia",
     "Week" : "Semana",
     "Month" : "Mês",
+    "Untitled calendar" : "Calendário sem titulo",
+    "Edit name" : "Editar nome",
+    "Edit color" : "Editar a cor",
     "Download" : "Transferir",
     "Delete" : "Eliminar",
     "Share link" : "Partilhar hiperligação",
+    "Publish calendar" : "Publicar calendário",
+    "Publishing calendar" : "A publicar o calendário",
+    "Enter one address" : "Introduza um endereço",
+    "Sending email …" : "A enviar o email …",
     "Delete share link" : "Apagar hiperligação de partilha",
+    "An error occurred, unable to publish calendar." : "Ocorreu um erro, não foi possível publicar o calendário.",
+    "An error occurred, unable to send email." : "Ocorreu um erro, não foi possível enviar o email.",
     "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
     "No users or groups" : "Sem utilizadores ou grupos",
     "can edit" : "pode editar",
+    "+ New calendar" : "+ Novo calendário",
     "New calendar" : "Novo calendário",
+    "Creating calendar …" : "A criar o calendário …",
+    "Import calendars" : "Importar calendários",
     "Filename" : "Nome do ficheiro",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "Actions" : "Ações",
+    "Enable birthday calendar" : "Ativar calendário de aniversários",
     "Show week numbers" : "Mostrar o número das semanas",
     "Settings & import" : "Definições & importar",
     "Notification" : "Notificação",
@@ -40,7 +59,6 @@ OC.L10N.register(
     "More" : "Mais",
     "Save" : "Guardar",
     "Update" : "Atualizar",
-    "Select Date" : "Escolha a data",
     "Personal" : "Pessoal",
     "Details" : "Detalhes",
     "Attendees" : "Participantes",
