@@ -20,6 +20,7 @@ OC.L10N.register(
     "Filename" : "Emri i skedarit",
     "Cancel" : "Anuloje",
     "Automatic" : "Automatike",
+    "Actions" : "Veprimet",
     "Show week numbers" : "Shfaq numra javësh",
     "Settings & import" : "Konfigurimet dhe importi",
     "Notification" : "Njoftim",
@@ -34,7 +35,6 @@ OC.L10N.register(
     "More" : "Më tepër",
     "Save" : "Ruaj",
     "Update" : "Përditësoje",
-    "Select Date" : "Zgjidhni Datën",
     "Personal" : "Personale",
     "Details" : "Detajet",
     "Attendees" : "Pjesëmarrës",
