@@ -53,6 +53,8 @@ OC.L10N.register(
     "Filename" : "檔案名稱",
     "Cancel" : "取消",
     "Automatic" : "自動",
+    "or" : "或者",
+    "Actions" : "動作",
     "Show week numbers" : "顯示週數",
     "Settings & import" : "設定及匯入",
     "Notification" : "通知",
@@ -90,7 +92,6 @@ OC.L10N.register(
     "More" : "更多",
     "Save" : "儲存",
     "Update" : "更新",
-    "Select Date" : "選擇日期",
     "from {formattedDate}" : "從 {formattedDate}",
     "to {formattedDate}" : "至 {formattedDate}",
     "Please enter a valid date" : "請輸入一個有效的日期",
